from __future__ import division, print_function
import argparse
import sys

p = argparse.ArgumentParser()
p.add_argument("-v", "--verbose", default=False, action="store_true")
args = p.parse_args()
gold_labels = []
with open("toydata") as f:
    for line in f:
        label, _, _, _, _ = line.strip().split('\t')
        gold_labels.append(int(label))

true_pos = 0
false_pos = 0
true_neg = 0
false_neg = 0
for idx, line in enumerate(sys.stdin):
    line = line.strip()
    if line not in ("1", "0"):
        sys.exit("ERROR: hypothesis labels should be 1 (about a person) or 0 (not about a person) - found {} instead".format(line))
    hyp = int(line)
    if hyp == gold_labels[idx]:
        if args.verbose:
            print("Line {} CORRECT".format(idx))
        if hyp:
            true_pos += 1
        else:
            true_neg += 1
    else:
        if args.verbose:
            print("Line {} INCORRECT".format(idx))
        if hyp:
            false_pos += 1
        else:
            false_neg += 1

print("Overall accuracy: {:.3f}%".format(100.0 * (true_pos + true_neg) / len(gold_labels)))
print("Overall precision: {:.3f}".format(true_pos / (true_pos + false_pos)))
print("Overall recall: {:.3f}".format(true_pos / (true_pos + false_neg)))
